<?php
/**
 * WeCodeArt Framework.
 *
 * WARNING: This file is part of the core WeCodeArt Framework. DO NOT edit this file under any circumstances.
 * Please do all modifications in the form of a child theme.
 *
 * @package 	WeCodeArt Framework
 * @subpackage 	Support\ANR Captcha
 * @copyright   Copyright (c) 2019, WeCodeArt Framework
 * @since 		3.8.1
 * @version		3.8.9
 */

namespace WeCodeArt\Support;

if ( ! defined( 'ABSPATH' ) ) exit;

use anr_captcha_class as Captcha;
use WeCodeArt\Utilities\Markup;

/**
 * ANR Integration
 * @see https://wordpress.org/plugins/advanced-nocaptcha-recaptcha/
 */
class ANR {

	use \WeCodeArt\Singleton; 

	/**
	 * Send to Constructor
	 */
	public function init() {
		add_action( 'init', [ $this, 'hooks' ] );
	}

	/**
	 * Hooks
	 *
	 * @since   3.8.1
	 *
	 * @return  void
	 */
	public function hooks() {
		if( apply_filters( 'wecodeart/filter/support/anr', true ) ) {
			$anr_instance = Captcha::init();

			if ( ! is_user_logged_in() ) {
				remove_action( 'comment_form_after_fields', 	[ $anr_instance, 'form_field' ], 99 );
				add_action( 'comment_form_after_fields', 		[ $this, 'wrapp_form_field' ] );
			} else {
				remove_filter( 'comment_form_field_comment', 	[ $anr_instance, 'comment_form_field' ], 99 );
				add_filter( 'comment_form_field_comment', 		[ $this, 'wrapp_comment_form_field' ] );
			}
		}
	}

	/**
	 * Comment Captcha
	 *
	 * @since   3.8.1
	 * @version	3.8.9
	 * @see 	anr_captcha_form_field();
	 * @uses	anr_captcha_class::init()->form_field();
	 *
	 * @return  void
	 */
	public function wrapp_form_field() {
		Markup::wrap( 'comment-captcha', [
			[ 'tag' => 'div', 'attrs' => [ 'class' => 'form-group comment-form-captcha col-12 col-md-7' ] ],
		], [ Captcha::init(), 'form_field' ] ); // Echoes the form_field().
	}

	/**
	 * Comment Captcha
	 *
	 * @since   3.8.1
	 * @version	3.8.9
	 * @see 	anr_captcha_class::init()->captcha_form_field();
	 * @uses	anr_captcha_class::init()->captcha_form_field();
	 *
	 * @return  void
	 */
	public function wrapp_comment_form_field( $defaults ) {
		$loggedin_hide = anr_get_option( 'loggedin_hide' );

		if ( is_user_logged_in() && $loggedin_hide ) {
			return $defaults;
		}

		$defaults .= Markup::wrap( 'comment-captcha', [
			[ 'tag' => 'div', 'attrs' => [ 'class' => 'form-group comment-form-captcha col-12 col-md-7' ] ],
		], [ Captcha::init(), 'captcha_form_field' ], [ true ], false );

		return $defaults;
	}
}