<?php
/**
 * WeCodeArt Framework
 *
 * WARNING: This file is part of the core WeCodeArt Framework. DO NOT edit this file under any circumstances.
 * Please do all modifications in the form of a child theme.
 *
 * @package 	WeCodeArt Framework 
 * @subpackage 	Utilities\Markup\Template
 * @copyright   Copyright (c) 2019, WeCodeArt Framework
 * @since		3.7.3
 */

namespace WeCodeArt\Utilities\Markup;

if ( ! defined( 'ABSPATH' ) ) exit(); 

class Template {
    /**
     * Theme config instance.
     *
     * @var array
     */
    protected $config;

    /**
     * File path to the template.
     *
     * @var string
     */
    protected $file;

    /**
     * Construct template.
     *
     * @param $config
     */
    public function __construct( array $config ) {
        $this->config = $config;
    }

    /**
     * Render template.
     *
     * @param  array $context
     * @throws Exception
     *
     * @return void
     */
    public function render( array $context = [] ) {
        if ( $template = locate_template( $path = $this->get_relative_path(), false, false ) ) {
            $this->do_actions();

            extract( apply_filters( "wecodeart/filter/template/{$this->get_filename()}/context", $context ) );

            require $template;

            return;
        }

        throw new \Exception( "Template file [{$this->get_relative_path()}] cannot be located." );
    }

    /**
     * Calls before including template actions.
     *
     * @return void
     */
    public function do_actions() {
        if ( $this->is_named() ) {
            list( $slug, $name ) = $this->file;

            do_action( "get_template_part_{$slug}", $slug, $name );

            return;
		}
		
        if ( is_array( $this->file ) && isset( $this->file[0] ) ) {
            return do_action( "get_template_part_{$this->file[0]}", $this->file[0], null );
        }

        do_action( "get_template_part_{$this->file}", $this->file, null );
    }

    /**
     * Gets absolute path to the template.
     *
     * @return string
     */
    public function get_path() {
        $directory = $this->config['directory'];
        return $directory . '/' . $this->get_relative_path();
    }

    /**
     * Gets template path within `views` directory.
     *
     * @return string
     */
    public function get_relative_path() {
        $templates = $this->config['templates'];

        $extension = $this->config['extension'];

        return $templates . '/' . $this->get_filename($extension);
    }

    /**
     * Gets template name.
     *
     * @return string
     */
    public function get_filename( $extension = '.php' ) {
        if ( $this->is_named() ) {
            return join( '-', $this->file ) . $extension;
		}
		
        if ( is_array( $this->file ) && isset( $this->file[0] ) ) {
            return "{$this->file[0]}{$extension}";
        }

        return apply_filters( 'wecodeart/filter/template/filename', "{$this->file}{$extension}" );
    }

    /**
     * Checks if temlate has variant name.
     *
     * @return boolean
     */
    public function is_named() {
        if ( ! is_array( $this->file ) ) {
            return false;
		}
		
        if ( isset( $this->file[1] ) && is_bool( $this->file[1] ) || null === $this->file[1] || empty( $this->file[1] ) ) {
            return false;
        }

        return true;
    }

    /**
     * Sets the file path to the template.
     *
     * @param string $file
     *
     * @return self
     */
    public function set_file( $file ) {
        $this->file = $file;

        return $this;
    }

    /**
     * Gets the File path to the template.
     *
     * @return string
     */
    public function get_file() {
        return $this->file;
    }
}